# pai-llm 
 
A pragmatic LLM library for Artificial Intelligence.

## Installation

```bash
pip install pai-llm
```

## Features

### v0.2.4

* Added conversation history support for langchain's ChatOpenAI.